@@ -60,7 +60,6 @@ class MYSQLExporter(Result):
         import MySQLdb
         if self.args.get_only_ff:
             aq="update tw_user set tw_id=\'%s\', task_status=1 where name=\'%s\'"
-
         else:
             print "Getting user data"
             aq= "update tw_user set tw_id=\'%s\', task_status=\'%s\', task_host=\'%s\', created_at=\'%s\', statuses_count=\'%s\', friend_count=\'%s\', followers_count=\'%s\', geo_lat=\'%s\', geo_long=\'%s\', geo_text=\'%s\' where  name=\'%s\'" ,
@@ -80,7 +79,7 @@ class MYSQLExporter(Result):
 
     def save(self, query, args, status=True):
         try:
-            print('Executing query %s' %(args))
+            print args
             self.sqlconn.cursor().execute(query %tuple(args))
             self.sqlconn.commit()
 
